==> kubernetes-model-extensions-5.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DeploymentStrategyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class DeploymentStrategyFluentImpl<A extends DeploymentStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DeploymentStrategyFluent<A> {

    private RollingUpdateDeploymentBuilder rollingUpdate;
    private String type;

    public DeploymentStrategyFluentImpl() {
    }

    public DeploymentStrategyFluentImpl(DeploymentStrategy instance) {
        this.withRollingUpdate(instance.getRollingUpdate()); 
        this.withType(instance.getType()); 
    }

    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public RollingUpdateDeployment getRollingUpdate() {
        return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public RollingUpdateDeployment buildRollingUpdate() {
        return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public A withRollingUpdate(RollingUpdateDeployment rollingUpdate) {
        _visitables.get("rollingUpdate").remove(this.rollingUpdate);
        if (rollingUpdate!=null){ this.rollingUpdate= new RollingUpdateDeploymentBuilder(rollingUpdate); _visitables.get("rollingUpdate").add(this.rollingUpdate);} return (A) this;
    }

    public Boolean hasRollingUpdate() {
        return this.rollingUpdate != null;
    }

    public DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate() {
        return new RollingUpdateNestedImpl();
    }

    public DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(RollingUpdateDeployment item) {
        return new RollingUpdateNestedImpl(item);
    }

    public DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate() {
        return withNewRollingUpdateLike(getRollingUpdate());
    }

    public DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate() {
        return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): new RollingUpdateDeploymentBuilder().build());
    }

    public DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(RollingUpdateDeployment item) {
        return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): item);
    }

    public String getType() {
        return this.type;
    }

    public A withType(String type) {
        this.type=type; return (A) this;
    }

    public Boolean hasType() {
        return this.type != null;
    }

    public A withNewType(String arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1) {
        return (A)withType(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DeploymentStrategyFluentImpl that = (DeploymentStrategyFluentImpl) o;
        if (rollingUpdate != null ? !rollingUpdate.equals(that.rollingUpdate) :that.rollingUpdate != null) return false;
        if (type != null ? !type.equals(that.type) :that.type != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(rollingUpdate,  type,  super.hashCode());
    }

    public class RollingUpdateNestedImpl<N> extends RollingUpdateDeploymentFluentImpl<DeploymentStrategyFluent.RollingUpdateNested<N>> implements DeploymentStrategyFluent.RollingUpdateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final RollingUpdateDeploymentBuilder builder;

            RollingUpdateNestedImpl(RollingUpdateDeployment item) {
                this.builder = new RollingUpdateDeploymentBuilder(this, item);
                        
            }

            RollingUpdateNestedImpl() {
                this.builder = new RollingUpdateDeploymentBuilder(this);
                        
            }

            public N and() {
                return (N) DeploymentStrategyFluentImpl.this.withRollingUpdate(builder.build());
            }

            public N endRollingUpdate() {
                return and();
            }
    }


}

==> kubernetes-model-extensions-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DeploymentStrategyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class DeploymentStrategyFluentImpl<A extends DeploymentStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DeploymentStrategyFluent<A> {

    private RollingUpdateDeploymentBuilder rollingUpdate;
    private String type;

    public DeploymentStrategyFluentImpl() {
    }

    public DeploymentStrategyFluentImpl(DeploymentStrategy instance) {
        this.withRollingUpdate(instance.getRollingUpdate()); 
        this.withType(instance.getType()); 
    }

    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public RollingUpdateDeployment getRollingUpdate() {
        return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public RollingUpdateDeployment buildRollingUpdate() {
        return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public A withRollingUpdate(RollingUpdateDeployment rollingUpdate) {
        _visitables.get("rollingUpdate").remove(this.rollingUpdate);
        if (rollingUpdate!=null){ this.rollingUpdate= new RollingUpdateDeploymentBuilder(rollingUpdate); _visitables.get("rollingUpdate").add(this.rollingUpdate);} return (A) this;
    }

    public Boolean hasRollingUpdate() {
        return this.rollingUpdate != null;
    }

    public io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate() {
        return new RollingUpdateNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(RollingUpdateDeployment item) {
        return new RollingUpdateNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent.RollingUpdateNested<A> editRollingUpdate() {
        return withNewRollingUpdateLike(getRollingUpdate());
    }

    public io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate() {
        return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): new RollingUpdateDeploymentBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(RollingUpdateDeployment item) {
        return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): item);
    }

    public String getType() {
        return this.type;
    }

    public A withType(String type) {
        this.type=type; return (A) this;
    }

    public Boolean hasType() {
        return this.type != null;
    }

    public A withNewType(StringBuilder arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(int[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(char[] arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(byte[] arg1,int arg2) {
        return (A)withType(new String(arg1, arg2));
    }

    public A withNewType(byte[] arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(char[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(byte[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withType(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewType(String arg1) {
        return (A)withType(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DeploymentStrategyFluentImpl that = (DeploymentStrategyFluentImpl) o;
        if (rollingUpdate != null ? !rollingUpdate.equals(that.rollingUpdate) :that.rollingUpdate != null) return false;
        if (type != null ? !type.equals(that.type) :that.type != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(rollingUpdate,  type,  super.hashCode());
    }

    public class RollingUpdateNestedImpl<N> extends RollingUpdateDeploymentFluentImpl<io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent.RollingUpdateNested<N>> implements io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent.RollingUpdateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final RollingUpdateDeploymentBuilder builder;

            RollingUpdateNestedImpl(RollingUpdateDeployment item) {
                this.builder = new RollingUpdateDeploymentBuilder(this, item);
                        
            }

            RollingUpdateNestedImpl() {
                this.builder = new RollingUpdateDeploymentBuilder(this);
                        
            }

            public N and() {
                return (N) DeploymentStrategyFluentImpl.this.withRollingUpdate(builder.build());
            }

            public N endRollingUpdate() {
                return and();
            }
    }


}
